@@ -1,12 +1,29 @@
 package Test::Auto::Types;
 
-use Data::Object 'Library';
+use strict;
+use warnings;
 
-our $VERSION = '0.05'; # VERSION
+use Type::Library -base;
+use Type::Utils -all;
+
+BEGIN {
+  extends 'Types::Standard';
+}
+
+our $VERSION = '0.06'; # VERSION
+
+declare 'Data',
+  as InstanceOf['Data::Object::Data'];
+
+declare 'Document',
+  as InstanceOf['Test::Auto::Document'];
 
 declare 'Parser',
   as InstanceOf['Test::Auto::Parser'];
 
+declare 'Plugin',
+  as InstanceOf['Test::Auto::Plugin'];
+
 declare 'Source',
   as InstanceOf['Test::Auto'];
 
@@ -48,6 +65,14 @@ This package provides type constraints for L<Test::Auto>.
 
 =cut
 
+=head1 INHERITS
+
+This package inherits behaviors from:
+
+L<Types::Standard>
+
+=cut
+
 =head1 CONSTRAINTS
 
 This package declares the following type constraints:
